@@ -22,7 +22,6 @@ pub use mpst_seq_proc::create_normal_role_short;
 pub use mpst_seq_proc::create_offer_mpst_session_multi;
 pub use mpst_seq_proc::create_offer_type_multi;
 pub use mpst_seq_proc::create_recv_http_session;
-pub use mpst_seq_proc::create_recv_mpst_all_session;
 pub use mpst_seq_proc::create_recv_mpst_session;
 pub use mpst_seq_proc::create_send_check_cancel;
 pub use mpst_seq_proc::create_send_http_session;
@@ -108,9 +107,6 @@ pub use mpst_seq_proc::e_create_send_check_cancel;
 #[proc_macro_hack]
 pub use mpst_seq_proc::e_create_recv_http_session;
 
-#[proc_macro_hack]
-pub use mpst_seq_proc::e_create_recv_mpst_all_session;
-
 #[proc_macro_hack]
 pub use mpst_seq_proc::e_send_mpst;
 
